@@ -16,25 +16,24 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
-
-from os.path import join
+from os.path import dirname, join
 from unittest.mock import Mock, patch
+from uuid import UUID
 
-from cyclonedx.exception.model import UnknownComponentDependencyException
 from cyclonedx.exception.output import FormatNotSupportedException
 from cyclonedx.model.bom import Bom
-from cyclonedx.output import OutputFormat, SchemaVersion, get_instance
-
-from . import FIXTURES_DIRECTORY, RECREATE_SNAPSHOTS
-from .base import BaseJsonTestCase
-from .data import (
+from cyclonedx.output import get_instance
+from cyclonedx.schema import OutputFormat, SchemaVersion
+from tests.base import BaseJsonTestCase
+from tests.data import (
     MOCK_UUID_1,
     MOCK_UUID_2,
     MOCK_UUID_3,
+    MOCK_UUID_4,
+    MOCK_UUID_5,
     MOCK_UUID_6,
     TEST_UUIDS,
     get_bom_for_issue_275_components,
-    get_bom_for_issue_328_components,
     get_bom_just_complete_metadata,
     get_bom_with_component_setuptools_basic,
     get_bom_with_component_setuptools_complete,
@@ -43,7 +42,6 @@ from .data import (
     get_bom_with_component_setuptools_with_release_notes,
     get_bom_with_component_setuptools_with_vulnerability,
     get_bom_with_component_toml_1,
-    get_bom_with_dependencies_invalid,
     get_bom_with_dependencies_valid,
     get_bom_with_external_references,
     get_bom_with_metadata_component_and_dependencies,
@@ -120,7 +118,7 @@ class TestOutputJson(BaseJsonTestCase):
             fixture='bom_setuptools_with_cpe.json'
         )
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_6)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
     def test_bom_v1_4_full_component(self, mock: Mock) -> None:
         self.maxDiff = None
         self._validate_json_bom(
@@ -129,7 +127,7 @@ class TestOutputJson(BaseJsonTestCase):
         )
         mock.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_6)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
     def test_bom_v1_3_full_component(self, mock: Mock) -> None:
         self._validate_json_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_3,
@@ -137,7 +135,7 @@ class TestOutputJson(BaseJsonTestCase):
         )
         mock.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_6)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
     def test_bom_v1_2_full_component(self, mock: Mock) -> None:
         self._validate_json_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_2,
@@ -206,7 +204,7 @@ class TestOutputJson(BaseJsonTestCase):
             fixture='bom_setuptools.json'
         )
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_1)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_1))
     def test_bom_v1_4_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
@@ -215,7 +213,7 @@ class TestOutputJson(BaseJsonTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_2)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_2))
     def test_bom_v1_3_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
@@ -224,7 +222,7 @@ class TestOutputJson(BaseJsonTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_3)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
     def test_bom_v1_2_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
@@ -233,86 +231,104 @@ class TestOutputJson(BaseJsonTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_simple.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_simple.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_simple.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_5))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_complex.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_5))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_complex.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_5))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_complex.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_nested.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_nested.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_json_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_nested.json'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
     def test_bom_v1_4_dependencies(self) -> None:
         self._validate_json_bom(
@@ -350,13 +366,6 @@ class TestOutputJson(BaseJsonTestCase):
             fixture='bom_dependencies_component.json'
         )
 
-    def test_bom_v1_4_dependencies_invalid(self) -> None:
-        with self.assertRaises(UnknownComponentDependencyException):
-            self._validate_json_bom(
-                bom=get_bom_with_dependencies_invalid(), schema_version=SchemaVersion.V1_4,
-                fixture='bom_dependencies.json'
-            )
-
     def test_bom_v1_4_issue_275_components(self) -> None:
         self._validate_json_bom(
             bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_4,
@@ -375,42 +384,16 @@ class TestOutputJson(BaseJsonTestCase):
             fixture='bom_issue_275_components.json'
         )
 
-    def test_bom_v1_4_issue_328_components(self) -> None:
-        self._validate_json_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_4,
-            fixture='bom_issue_328_components.json'
-        )
-
-    def test_bom_v1_3_issue_328_components(self) -> None:
-        self._validate_json_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_3,
-            fixture='bom_issue_328_components.json'
-        )
-
-    def test_bom_v1_2_issue_328_components(self) -> None:
-        self._validate_json_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_2,
-            fixture='bom_issue_328_components.json'
-        )
-
     # region Helper methods
 
     def _validate_json_bom(self, bom: Bom, schema_version: SchemaVersion, fixture: str) -> None:
         outputter = get_instance(bom=bom, output_format=OutputFormat.JSON, schema_version=schema_version)
         self.assertEqual(outputter.schema_version, schema_version)
-        output = outputter.output_as_string()
-        self.assertValidAgainstSchema(bom_json=output, schema_version=schema_version)
-        fixture_file = join(
-            FIXTURES_DIRECTORY,
-            'json',
-            schema_version.to_version(),
-            fixture
-        )
-        if RECREATE_SNAPSHOTS:
-            with open(fixture_file, 'w') as expected_json:
-                expected_json.write(output)
-        with open(fixture_file) as expected_json:
-            self.assertEqualJsonBom(expected_json.read(), output)
+        with open(
+                join(dirname(__file__), f'fixtures/json/{schema_version.to_version()}/{fixture}')) as expected_json:
+            output_as_string = outputter.output_as_string()
+            self.assertValidAgainstSchema(bom_json=output_as_string, schema_version=schema_version)
+            self.assertEqualJsonBom(expected_json.read(), output_as_string)
 
     def _validate_json_bom_not_supported(self, bom: Bom, schema_version: SchemaVersion) -> None:
         with self.assertRaises(FormatNotSupportedException):
