@@ -16,17 +16,15 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
-
-from os.path import join
+from os.path import dirname, join
 from unittest.mock import Mock, patch
+from uuid import UUID
 
-from cyclonedx.exception.model import UnknownComponentDependencyException
 from cyclonedx.model.bom import Bom
-from cyclonedx.output import SchemaVersion, get_instance
-
-from . import FIXTURES_DIRECTORY, RECREATE_SNAPSHOTS
-from .base import BaseXmlTestCase
-from .data import (
+from cyclonedx.output import get_instance
+from cyclonedx.schema import SchemaVersion
+from tests.base import BaseXmlTestCase
+from tests.data import (
     MOCK_UUID_1,
     MOCK_UUID_2,
     MOCK_UUID_3,
@@ -35,7 +33,6 @@ from .data import (
     MOCK_UUID_6,
     TEST_UUIDS,
     get_bom_for_issue_275_components,
-    get_bom_for_issue_328_components,
     get_bom_just_complete_metadata,
     get_bom_with_component_setuptools_basic,
     get_bom_with_component_setuptools_complete,
@@ -44,7 +41,6 @@ from .data import (
     get_bom_with_component_setuptools_with_release_notes,
     get_bom_with_component_setuptools_with_vulnerability,
     get_bom_with_component_toml_1,
-    get_bom_with_dependencies_invalid,
     get_bom_with_dependencies_valid,
     get_bom_with_external_references,
     get_bom_with_metadata_component_and_dependencies,
@@ -147,7 +143,7 @@ class TestOutputXml(BaseXmlTestCase):
             fixture='bom_setuptools_with_cpe.xml'
         )
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_4)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
     def test_bom_v1_4_full_component(self, mock_uuid: Mock) -> None:
         self._validate_xml_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_4,
@@ -155,7 +151,7 @@ class TestOutputXml(BaseXmlTestCase):
         )
         mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_3)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
     def test_bom_v1_3_full_component(self, mock_uuid: Mock) -> None:
         self._validate_xml_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_3,
@@ -163,7 +159,7 @@ class TestOutputXml(BaseXmlTestCase):
         )
         mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_2)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_2))
     def test_bom_v1_2_full_component(self, mock_uuid: Mock) -> None:
         self._validate_xml_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_2,
@@ -171,7 +167,7 @@ class TestOutputXml(BaseXmlTestCase):
         )
         mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_1)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_1))
     def test_bom_v1_1_full_component(self, mock_uuid: Mock) -> None:
         self._validate_xml_bom(
             bom=get_bom_with_component_setuptools_complete(), schema_version=SchemaVersion.V1_1,
@@ -263,31 +259,13 @@ class TestOutputXml(BaseXmlTestCase):
             fixture='bom_setuptools_with_vulnerabilities.xml'
         )
 
-    def test_bom_v1_3_component_with_vulnerability(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_component_setuptools_with_vulnerability(), schema_version=SchemaVersion.V1_3,
-            fixture='bom_setuptools_with_vulnerabilities.xml'
-        )
-
-    def test_bom_v1_2_component_with_vulnerability(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_component_setuptools_with_vulnerability(), schema_version=SchemaVersion.V1_2,
-            fixture='bom_setuptools_with_vulnerabilities.xml'
-        )
-
-    def test_bom_v1_1_component_with_vulnerability(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_component_setuptools_with_vulnerability(), schema_version=SchemaVersion.V1_1,
-            fixture='bom_setuptools_with_vulnerabilities.xml'
-        )
-
     def test_bom_v1_0_component_with_vulnerability(self) -> None:
         self._validate_xml_bom(
             bom=get_bom_with_component_setuptools_with_vulnerability(), schema_version=SchemaVersion.V1_0,
             fixture='bom_setuptools.xml'
         )
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_6)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
     def test_bom_v1_4_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
@@ -296,7 +274,7 @@ class TestOutputXml(BaseXmlTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_5)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_5))
     def test_bom_v1_3_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
@@ -305,7 +283,7 @@ class TestOutputXml(BaseXmlTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_4)
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
     def test_bom_v1_2_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
@@ -314,7 +292,7 @@ class TestOutputXml(BaseXmlTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_1)
+    @patch('cyclonedx.model.bom.uuid4', return_value=UUID(MOCK_UUID_1))
     def test_bom_v1_1_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
@@ -323,7 +301,7 @@ class TestOutputXml(BaseXmlTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', return_value=MOCK_UUID_1)
+    @patch('cyclonedx.model.bom.uuid4', return_value=UUID(MOCK_UUID_1))
     def test_bom_v1_0_with_metadata_component(self, mock_uuid: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
@@ -332,113 +310,137 @@ class TestOutputXml(BaseXmlTestCase):
             )
             mock_uuid.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_simple.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_simple.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_simple.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_1_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_1_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_1,
                 fixture='bom_empty.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_0_services_simple(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_3))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_0_services_simple(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_simple(), schema_version=SchemaVersion.V1_0,
                 fixture='bom_empty.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_complex(self, mock_uuid4: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_complex.xml'
             )
-            mock_uuid4.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_complex.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_4))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_complex.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_1_services_complex(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_2))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_1_services_complex(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_services_complex(), schema_version=SchemaVersion.V1_1,
                 fixture='bom_empty.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_4_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_4_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_4,
                 fixture='bom_services_nested.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_3_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_3_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_3,
                 fixture='bom_services_nested.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
-    @patch('cyclonedx.model.bom_ref.uuid4', side_effect=TEST_UUIDS)
-    def test_bom_v1_2_services_nested(self, mock_uuid: Mock) -> None:
+    @patch('cyclonedx.model.component.uuid4', return_value=UUID(MOCK_UUID_6))
+    @patch('cyclonedx.model.service.uuid4', side_effect=TEST_UUIDS)
+    def test_bom_v1_2_services_nested(self, mock_1: Mock, mock_2: Mock) -> None:
         with self.assertWarns(UserWarning):
             self._validate_xml_bom(
                 bom=get_bom_with_nested_services(), schema_version=SchemaVersion.V1_2,
                 fixture='bom_services_nested.xml'
             )
-            mock_uuid.assert_called()
+            mock_1.assert_called()
+            mock_2.assert_called()
 
     def test_bom_v1_4_dependencies(self) -> None:
         self._validate_xml_bom(
@@ -465,107 +467,72 @@ class TestOutputXml(BaseXmlTestCase):
         )
 
     def test_bom_v1_4_dependencies_for_bom_component(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_4,
-            fixture='bom_dependencies_component.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_4,
+                fixture='bom_dependencies_component.xml'
+            )
 
     def test_bom_v1_3_dependencies_for_bom_component(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_3,
-            fixture='bom_dependencies_component.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_3,
+                fixture='bom_dependencies_component.xml'
+            )
 
     def test_bom_v1_2_dependencies_for_bom_component(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_2,
-            fixture='bom_dependencies_component.xml'
-        )
-
-    def test_bom_v1_4_dependencies_invalid(self) -> None:
-        with self.assertRaises(UnknownComponentDependencyException):
+        with self.assertWarns(UserWarning):
             self._validate_xml_bom(
-                bom=get_bom_with_dependencies_invalid(), schema_version=SchemaVersion.V1_4,
-                fixture='bom_dependencies.xml'
+                bom=get_bom_with_metadata_component_and_dependencies(), schema_version=SchemaVersion.V1_2,
+                fixture='bom_dependencies_component.xml'
             )
 
     def test_bom_v1_4_issue_275_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_4,
-            fixture='bom_issue_275_components.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_4,
+                fixture='bom_issue_275_components.xml'
+            )
 
     def test_bom_v1_3_issue_275_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_3,
-            fixture='bom_issue_275_components.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_3,
+                fixture='bom_issue_275_components.xml'
+            )
 
     def test_bom_v1_2_issue_275_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_2,
-            fixture='bom_issue_275_components.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_2,
+                fixture='bom_issue_275_components.xml'
+            )
 
     def test_bom_v1_1_issue_275_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_1,
-            fixture='bom_issue_275_components.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_1,
+                fixture='bom_issue_275_components.xml'
+            )
 
     def test_bom_v1_0_issue_275_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_0,
-            fixture='bom_issue_275_components.xml'
-        )
-
-    def test_bom_v1_4_issue_328_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_4,
-            fixture='bom_issue_328_components.xml'
-        )
-
-    def test_bom_v1_3_issue_328_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_3,
-            fixture='bom_issue_328_components.xml'
-        )
-
-    def test_bom_v1_2_issue_328_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_2,
-            fixture='bom_issue_328_components.xml'
-        )
-
-    def test_bom_v1_1_issue_328_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_1,
-            fixture='bom_issue_328_components.xml'
-        )
-
-    def test_bom_v1_0_issue_328_components(self) -> None:
-        self._validate_xml_bom(
-            bom=get_bom_for_issue_328_components(), schema_version=SchemaVersion.V1_0,
-            fixture='bom_issue_328_components.xml'
-        )
+        with self.assertWarns(UserWarning):
+            self._validate_xml_bom(
+                bom=get_bom_for_issue_275_components(), schema_version=SchemaVersion.V1_0,
+                fixture='bom_issue_275_components.xml'
+            )
 
     # region Helper methods
 
     def _validate_xml_bom(self, bom: Bom, schema_version: SchemaVersion, fixture: str) -> None:
         outputter = get_instance(bom=bom, schema_version=schema_version)
         self.assertEqual(outputter.schema_version, schema_version)
-        output = outputter.output_as_string()
-        self.assertValidAgainstSchema(bom_xml=output, schema_version=schema_version)
-        fixture_file = join(
-            FIXTURES_DIRECTORY,
-            'xml',
-            schema_version.to_version(),
-            fixture
-        )
-        if RECREATE_SNAPSHOTS:
-            with open(fixture_file, 'w') as expected_xml:
-                expected_xml.write(output)
-        with open(fixture_file) as expected_xml:
-            self.assertEqualXmlBom(expected_xml.read(), output, namespace=outputter.get_target_namespace())
+        with open(
+                join(dirname(__file__), f'fixtures/xml/{schema_version.to_version()}/{fixture}')) as expected_xml:
+            output_as_string = outputter.output_as_string()
+            self.assertValidAgainstSchema(bom_xml=output_as_string, schema_version=schema_version)
+            self.assertEqualXmlBom(
+                expected_xml.read(), output_as_string, namespace=outputter.get_target_namespace()
+            )
 
     # endregion Helper methods
